ExoTiC-MIRI
===========

**Custom steps for JWST MIRI LRS data reduction. Interoperable with the STScI pipeline.**

.. image:: https://img.shields.io/badge/powered_by-JWST-gold.svg
   :target: https://github.com/spacetelescope/jwst

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg
   :target: http://www.astropy.org/
   
.. image:: https://readthedocs.org/projects/exotic-miri/badge/?version=latest
   :target: https://exotic-miri.readthedocs.io/en/latest/?badge=latest

|

::

   pip install exotic-miri

| Read the full documentation at: `exotic-miri.readthedocs.io <https://exotic-miri.readthedocs.io/>`_
